# Do Not Go Gentle Into That Good Night

Do not go gentle into that good night,
Old age should burn and rave at close of day;
Rage, rage against the dying of the light.

Though wise men at their end know dark is right,
Because their words had forked no lightning they
Do not go gentle into that good night.

Good men, the last wave by, crying how bright
Their frail deeds might have danced in a green bay,
Rage, rage against the dying of the light.

Wild men who caught and sang the sun in flight,
And learn, too late, they grieve it on its way,
Do not go gentle into that good night.

Grave men, near death, who see with blinding sight
Blind eyes could blaze like meteors and be gay,
Rage, rage against the dying of the light.

And you, my father, there on the sad height,
Curse, bless, me now with your fierce tears, I pray.
Do not go gentle into that good night.
Rage, rage against the dying of the light.

  -- Dylan Thomas

[//]: # (aletheia:{"version":2,"domain":"example.com","signature":"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"})